summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmslopeedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmslopeedit.h')
-rw-r--r--kpovmodeler/pmslopeedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmslopeedit.h b/kpovmodeler/pmslopeedit.h
index a57816a1..cf262ab9 100644
--- a/kpovmodeler/pmslopeedit.h
+++ b/kpovmodeler/pmslopeedit.h
@@ -44,9 +44,9 @@ class PMSlopeEdit : public PMDialogEditBase
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMSlopeEdit with tqparent and name
*/
- PMSlopeEdit( TQWidget* tqparent, const char* name = 0 );
+ PMSlopeEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -44,9 +44,9 @@ class PMSlopeEdit : public PMDialogEditBase
public:
/**
- * Creates a PMSlopeEdit with tqparent and name
+ * Creates a PMSlopeEdit with parent and name
*/